bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.plates_from_parent
============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.plates_from_parent